Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(861)

Unified Diff: media/mojo/clients/mojo_cdm.h

Issue 2268283003: media: Add External Clear Key content browser test on Android (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix compile error Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/mojo/clients/mojo_cdm.h
diff --git a/media/mojo/clients/mojo_cdm.h b/media/mojo/clients/mojo_cdm.h
index 087910479c572c8f041d07a62a5d03a8d5636638..6fa8fd04c8a86f8a43ef896bd6989d4f2a2302df 100644
--- a/media/mojo/clients/mojo_cdm.h
+++ b/media/mojo/clients/mojo_cdm.h
@@ -147,10 +147,10 @@ class MojoCdm : public MediaKeys,
// be invalid if initialization succeeded.
int cdm_id_;
- // The DecryptorPtr exposed by the remote CDM. Set after initialization is
- // completed and cleared after |decryptor_| is created. May be null after
- // initialization if the CDM doesn't support a Decryptor.
- mojom::DecryptorPtr decryptor_ptr_;
+ // The DecryptorPtrInfo exposed by the remote CDM. Set after initialization
+ // is completed and cleared after |decryptor_| is created. May be invalid
+ // after initialization if the CDM doesn't support a Decryptor.
+ mojom::DecryptorPtrInfo decryptor_ptr_info_;
// Decryptor based on |decryptor_ptr_|, lazily created in GetDecryptor().
// Since GetDecryptor() can be called on a different thread, use

Powered by Google App Engine
This is Rietveld 408576698